@@ -28,6 +28,7 @@ def main_load(
     method=None,
     dataframe=None,
     outputfile=None,
+    fields=None,
     start=None,
     end=None,
     on_progress=None,
@@ -62,6 +63,7 @@ def main_load(
                         method,
                         dataframe,
                         outputfile,
+                        fields,
                         on_progress,
                     )
 
@@ -73,6 +75,7 @@ def main_load(
                         method,
                         dataframe,
                         outputfile,
+                        fields,
                         start,
                         end,
                         on_progress,
