@@ -39,6 +39,7 @@ def execute(
     methode,
     dataframe,
     outputfile=None,
+    fields=None,
     start=0,
     end=None,
     on_progress=None,
@@ -99,7 +100,7 @@ def execute(
 
                 r = controller.sendresults(url, headers, data)
                 df, data, chunk = controller.saveresults(
-                    r, df, program, index, chunk, MaxChunk, methode_count
+                    r, df, program, index, chunk, MaxChunk, methode_count, fields
                 )
                 data1 = {}
                 a = []
@@ -112,7 +113,7 @@ def execute(
         r = controller.sendresults(url, headers, data)
         index = index + 1
         df, data, chunk = controller.saveresults(
-            r, df, methode, index, chunk, MaxChunk, methode_count
+            r, df, methode, index, chunk, MaxChunk, methode_count, fields
         )
 
     # df = df.replace(np.nan, '', regex=True)
