@@ -230,6 +230,18 @@ def header():
     }
     return headers
 
+def get_headers_info(ionfile):
+
+    load_config(ionfile)
+    token = login()
+
+    headers = header()
+    if "Bearer" not in headers["Authorization"]:
+        logging.info("Error: InforION Login is not working")
+        sys.exit(0)
+    
+    return headers
+
 
 def base_url():
     return this._GLOBAL_url + "/" + this._GLOBAL_ti
